@@ -45,16 +45,6 @@ class DatatapProxy(base.BaseProxy):
             "wait_for_state",
         ]
 
-    def examples(self):
-        """Show examples for working with roles."""
-        print(
-            dedent(
-                """\
-                    Coming soon ...
-                """  # noqa:  E501
-            )
-        )
-
     @base.intercept_exception
     def create_hdfs_with_kerberos(
         self,
@@ -132,3 +122,15 @@ class DatatapProxy(base.BaseProxy):
             port=port,
             read_only=read_only,
         )
+
+    def examples(self):
+        """Show examples for working with roles."""
+        print(
+            dedent(
+                """\
+                # lookup datatap by name and retrieve ID
+                $ PROFILE=tenant2 hpecp datatap list --query "[?_embedded.label.name=='int-mapr-generic'] | [0] | [_links.self.href]" --output text
+                /api/v1/dataconn/11
+                """  # noqa:  E501
+            )
+        )
